/*
*  Rubrica
*  file: dictionary.c
*
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <gconf/gconf-client.h>
#include <gnome-xml/tree.h>
#include <gnome-xml/parser.h>

#include "dictionary.h"
#include "prefer.h"

Dictionary dict;
gboolean have_dict = FALSE;

RubricaDictionary rubrica_dict[] = {
  {ADDRESS, "Indirizzo", "Address", "" },
  {CARD, "Scheda", "Card", "" },
  {MODIFYING, "editabile", "modifying", "" },
  {DELETING, "cancellabile", "deleting", "" },
  {PERSONAL_DATA, "Dati", "Data", "" },
  {FIRST_NAME, "Nome", "FirstName", "" },
  {LAST_NAME, "Cognome", "LastName", "" },
  {PROFESSION, "Professione", "Profession", "" },
  {STREET, "Via", "Street", "" },
  {STREET_NUMBER, "Numero", "StreetNumber", "" },
  {ZIP_CODE, "Cap", "ZipCode", "" },
  {CITY, "Citta", "City", "" },
  {PROVINCE, "Provincia", "Province", ""},
  {COUNTRY, "Stato", "Country", ""},
  {WEB_ADDRESS, "IndirizziWeb", "WebAddresses", ""},
  {WEB, "Web", "Web", ""},
  {EMAIL_ADDRESS, "IndirizziEmail", "EmailAddresses", ""},
  {EMAIL, "EMail", "EMail", ""},
  {TELEPHONE_NUMBERS, "NumeriTelefonici", "TelephoneNumbers", ""},
  {TELEPHONE, "Telefono", "Telephone", ""},
  {TYPE, "tipo", "type", ""},
  {PUBLIC_KEY, "ChiavePublica", "PublicKey", ""},
  {NOTE, "Note", "Notes", ""},
  {NO_CODE, "Time", "Time", ""},
  {END, NULL, NULL, NULL}
};

void rubrica_dictionary_init(GConfClient *client)
{
  LANG langcode;
  gchar *language;
  gchar *dictionary;

  /* default language code */
  langcode = ENGLISH;
  
  if (rubrica_preferences_get_user_has_dictionary() &&
      rubrica_preferences_get_use_user_dictionary())
    {
      dictionary = rubrica_preferences_get_user_dictionary();
      language = rubrica_preferences_get_language();
      rubrica_dictionary_load_user_dictionary(client, dictionary, language);
    }

  switch (langcode)
    {
    case ITALIAN:
      rubrica_dictionary_get_italian();
      have_dict = TRUE;
      break;

    case ENGLISH:
      rubrica_dictionary_get_english();
      have_dict = TRUE;
      break; 

    case OTHER:
      rubrica_dictionary_get_other();
      have_dict = TRUE;
      break;  

    default:
      break;
    }
}

void rubrica_dictionary_get_italian(void)
{
  if (have_dict)
    rubrica_dictionary_clean();

  dict.address   = g_strdup(rubrica_dict[0].itstr);
  dict.card      = g_strdup(rubrica_dict[1].itstr);
  dict.modifying = g_strdup(rubrica_dict[2].itstr);
  dict.deleting  = g_strdup(rubrica_dict[3].itstr);
  dict.data     = g_strdup(rubrica_dict[4].itstr);
  dict.firstname     = g_strdup(rubrica_dict[5].itstr);
  dict.lastname     = g_strdup(rubrica_dict[6].itstr);
  dict.profession     = g_strdup(rubrica_dict[7].itstr);
  dict.street      = g_strdup(rubrica_dict[8].itstr);
  dict.streetnumber      = g_strdup(rubrica_dict[9].itstr);
  dict.zipcode      = g_strdup(rubrica_dict[10].itstr);
  dict.city     = g_strdup(rubrica_dict[11].itstr);
  dict.province     = g_strdup(rubrica_dict[12].itstr);
  dict.country       = g_strdup(rubrica_dict[13].itstr);
  dict.webaddresses   = g_strdup(rubrica_dict[14].itstr);
  dict.web      = g_strdup(rubrica_dict[15].itstr);
  dict.mailaddresses  = g_strdup(rubrica_dict[16].itstr);
  dict.mail     = g_strdup(rubrica_dict[17].itstr);
  dict.tellist  = g_strdup(rubrica_dict[18].itstr);
  dict.telnum   = g_strdup(rubrica_dict[19].itstr);
  dict.teltype  = g_strdup(rubrica_dict[20].itstr);
  dict.pubkey   = g_strdup(rubrica_dict[21].itstr);
  dict.note     = g_strdup(rubrica_dict[22].itstr);
  dict.lastchange     = g_strdup(rubrica_dict[23].itstr);
}

void rubrica_dictionary_get_english(void)
{
  if(have_dict)
    rubrica_dictionary_clean();

  dict.address  = g_strdup(rubrica_dict[0].enstr);
  dict.card     = g_strdup(rubrica_dict[1].enstr);
  dict.modifying      = g_strdup(rubrica_dict[2].enstr);
  dict.deleting      = g_strdup(rubrica_dict[3].enstr);
  dict.data     = g_strdup(rubrica_dict[4].enstr);
  dict.firstname     = g_strdup(rubrica_dict[5].enstr);
  dict.lastname     = g_strdup(rubrica_dict[6].enstr);
  dict.profession     = g_strdup(rubrica_dict[7].enstr);
  dict.street      = g_strdup(rubrica_dict[8].enstr);
  dict.streetnumber      = g_strdup(rubrica_dict[9].enstr);
  dict.zipcode      = g_strdup(rubrica_dict[10].enstr);
  dict.city     = g_strdup(rubrica_dict[11].enstr);
  dict.province     = g_strdup(rubrica_dict[12].enstr);
  dict.country       = g_strdup(rubrica_dict[13].enstr);
  dict.webaddresses   = g_strdup(rubrica_dict[14].enstr);
  dict.web      = g_strdup(rubrica_dict[15].enstr);
  dict.mailaddresses  = g_strdup(rubrica_dict[16].enstr);
  dict.mail     = g_strdup(rubrica_dict[17].enstr);
  dict.tellist  = g_strdup(rubrica_dict[18].enstr);
  dict.telnum   = g_strdup(rubrica_dict[19].enstr);
  dict.teltype  = g_strdup(rubrica_dict[20].enstr);
  dict.pubkey   = g_strdup(rubrica_dict[21].enstr);
  dict.note     = g_strdup(rubrica_dict[22].enstr);
  dict.lastchange     = g_strdup(rubrica_dict[23].enstr);
}

void rubrica_dictionary_get_other(void)
{
  if (have_dict)
    rubrica_dictionary_clean();

  dict.address  = g_strdup(rubrica_dict[0].trans);
  dict.card     = g_strdup(rubrica_dict[1].trans);
  dict.modifying      = g_strdup(rubrica_dict[2].trans);
  dict.deleting      = g_strdup(rubrica_dict[3].trans);
  dict.data     = g_strdup(rubrica_dict[4].trans);
  dict.firstname     = g_strdup(rubrica_dict[5].trans);
  dict.lastname     = g_strdup(rubrica_dict[6].trans);
  dict.profession     = g_strdup(rubrica_dict[7].trans);
  dict.street      = g_strdup(rubrica_dict[8].trans);
  dict.streetnumber      = g_strdup(rubrica_dict[9].trans);
  dict.zipcode      = g_strdup(rubrica_dict[10].trans);
  dict.city     = g_strdup(rubrica_dict[11].trans);
  dict.province     = g_strdup(rubrica_dict[12].trans);
  dict.country       = g_strdup(rubrica_dict[13].trans);
  dict.webaddresses   = g_strdup(rubrica_dict[14].trans);
  dict.web      = g_strdup(rubrica_dict[15].trans);
  dict.mailaddresses  = g_strdup(rubrica_dict[16].trans);
  dict.mail     = g_strdup(rubrica_dict[17].trans);
  dict.tellist  = g_strdup(rubrica_dict[18].trans);
  dict.telnum   = g_strdup(rubrica_dict[19].trans);
  dict.teltype  = g_strdup(rubrica_dict[20].trans);
  dict.pubkey   = g_strdup(rubrica_dict[21].trans);
  dict.note     = g_strdup(rubrica_dict[22].trans);
  dict.lastchange     = g_strdup(rubrica_dict[23].trans);
}

void rubrica_dictionary_clean()
{
  g_free(dict.address);  
  g_free(dict.card);
  g_free(dict.modifying);
  g_free(dict.deleting);
  g_free(dict.data);     
  g_free(dict.firstname);    
  g_free(dict.lastname);     
  g_free(dict.profession);     
  g_free(dict.street);      
  g_free(dict.streetnumber);     
  g_free(dict.zipcode);     
  g_free(dict.city);     
  g_free(dict.province);     
  g_free(dict.country);       
  g_free(dict.webaddresses);   
  g_free(dict.web);      
  g_free(dict.mailaddresses);  
  g_free(dict.mail);     
  g_free(dict.telnum);   
  g_free(dict.teltype);  
  g_free(dict.pubkey);   
  g_free(dict.note);
  g_free(dict.lastchange);

  have_dict = FALSE;
}


void rubrica_dictionary_load_translation()
{
  LANG language;

  if (!rubrica_preferences_get_user_has_dictionary)
    {      
//     language = preferences_get_lang_code();

      if (language == ITALIAN)
	rubrica_dictionary_get_italian();
      else
	rubrica_dictionary_get_english();
    }
  rubrica_dictionary_get_other();
}

Dictionary rubrica_dictionary_get_dictionary(gchar *sh_lang)
{
  if (sh_lang == NULL)
      return (Dictionary) dict;

  if (g_strcasecmp(sh_lang, "IT") == 0)
      rubrica_dictionary_get_italian();      
  else
    if (g_strcasecmp(sh_lang, "EN") == 0)
      rubrica_dictionary_get_english();     

  return (Dictionary) dict; 
}

void rubrica_dictionary_store_dictionary(Dictionary dict)
{
  rubrica_dict[0].trans = g_strdup(dict.address);
  rubrica_dict[1].trans = g_strdup(dict.card);
  rubrica_dict[2].trans = g_strdup(dict.modifying);
  rubrica_dict[3].trans = g_strdup(dict.deleting);
  rubrica_dict[4].trans = g_strdup(dict.data);
  rubrica_dict[5].trans = g_strdup(dict.firstname);
  rubrica_dict[6].trans = g_strdup(dict.lastname);
  rubrica_dict[7].trans = g_strdup(dict.profession);
  rubrica_dict[8].trans = g_strdup(dict.street);
  rubrica_dict[9].trans = g_strdup(dict.streetnumber);
  rubrica_dict[10].trans = g_strdup(dict.zipcode);
  rubrica_dict[11].trans = g_strdup(dict.city);
  rubrica_dict[12].trans = g_strdup(dict.province);
  rubrica_dict[13].trans = g_strdup(dict.country);
  rubrica_dict[14].trans = g_strdup(dict.webaddresses);
  rubrica_dict[15].trans = g_strdup(dict.web);
  rubrica_dict[16].trans = g_strdup(dict.mailaddresses);
  rubrica_dict[17].trans = g_strdup(dict.mail);
  rubrica_dict[18].trans = g_strdup(dict.tellist);
  rubrica_dict[19].trans = g_strdup(dict.telnum);
  rubrica_dict[20].trans = g_strdup(dict.teltype);
  rubrica_dict[21].trans = g_strdup(dict.pubkey);
  rubrica_dict[22].trans = g_strdup(dict.note);
  rubrica_dict[23].trans = g_strdup(dict.lastchange);
}


/*
  return TRUE if an error has occurred
  return FALSE if error hasn't occurred
 */
gboolean rubrica_dictionary_load_user_dictionary(GConfClient* client, 
						 gchar *dictionary,
						 gchar *language)
{
  xmlDocPtr doc;
  xmlNodePtr node;
  gchar *lang;
  gchar *home;
  gchar *dict_dir;
  
  home = g_get_home_dir();
  dict_dir = g_strdup_printf("%s/.rubrica/dictionary", home);
  
  if (!g_file_exists(dict_dir))
    mkdir(dict_dir, S_IRUSR | S_IWUSR | S_IXUSR);
      
  if (!g_file_exists(dictionary))
    {
      g_warning(_("The requested dictionary, %s.dict, don't exist."), lang);
      return TRUE;
    }
  
  doc = xmlParseFile(dictionary);
  if (!doc)
    {
      g_warning(_("I can't read the %s.dict dictionary"),lang);      
      return TRUE;
    }

   if (!doc->root || !doc->root->name || 
      g_strcasecmp(doc->root->name, "Rubrica_dictionary") != 0)
    {
      g_warning(_("This dictionary is corrupted\nHeader don't match with \"Rubrica_dictionary\"\nI can't read this dictionary"));
      xmlFreeDoc(doc);
      return TRUE;
    } 

   lang = xmlNodeGetLang(doc->root); 
   
   node = doc->root->childs;

   while (node)
     {
       rubrica_dictionary_parse_node(client, node);
       node = node->next;
     }   

   xmlFreeDoc(doc);
   rubrica_dictionary_store_dictionary(dict);
   
   return FALSE;
}

void rubrica_dictionary_parse_node(GConfClient *client, xmlNodePtr node)
{
  gchar *buffer;

  if (strcmp(node->name, "General") == 0)
    {
      buffer = xmlGetProp(node, "Address");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_ADDRESS, 
			      buffer ? buffer : "", NULL);
      buffer = xmlGetProp(node, "Card");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_CARD, 
			      buffer ? buffer : "", NULL);      
      buffer = xmlGetProp(node, "Modifying");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_MODIFY, 
			      buffer ? buffer : "", NULL);
      buffer = xmlGetProp(node, "Deleting");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_DELETE, 
			      buffer ? buffer : "", NULL);
      buffer = xmlGetProp(node, "Data");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_DATA, 
			      buffer ? buffer : "", NULL);   
    }
  else if (strcmp(node->name, "Personal") == 0)
    {
      buffer = xmlGetProp(node, "FirstName");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_FIRST_NAME, 
			      buffer ? buffer : "", NULL);      
      buffer = xmlGetProp(node, "MiddleName");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_MIDDLE_NAME, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "LastName");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_LAST_NAME, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "Profession");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_PROFESSION, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "Street");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_STREET, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "StreetNumber");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_STREET_NUMBER, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "ZipCode");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_ZIP_CODE, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "City");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_CITY, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "Province");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_PROVINCE, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "Country");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_COUNTRY, 
			      buffer ? buffer : "", NULL);   
    }

  else if (strcmp(node->name, "Net") == 0)
    {
      buffer = xmlGetProp(node, "WebAddress");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_WEB_ADDRESS, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "Web");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_WEB, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "EmailAddress");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_EMAIL_ADDRESS, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "Email");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_EMAIL, 
			      buffer ? buffer : "", NULL);   
    }
  else if (strcmp(node->name, "Telephone") == 0)
    {
      buffer = xmlGetProp(node, "TelephoneNumbers");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_TELEPHONE_LIST, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "Telephone");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_TELEPHONE_NUMBER, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "TelephoneType");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_TELEPHONE_TYPE, 
			      buffer ? buffer : "", NULL);         
    }
  else if (strcmp(node->name, "Misc") == 0)
    {
      buffer = xmlGetProp(node, "PublicKey");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_PUBLIC_KEY, 
			      buffer ? buffer : "", NULL);   
      buffer = xmlGetProp(node, "Notes");
      gconf_client_set_string(client, RUBRICA_KEY_DICT_NOTES, 
			      buffer ? buffer : "", NULL);
      
    }
  else
    return;
}

gboolean rubrica_dictionary_save_user_dictionary(GConfClient *client, 
						 gchar *dictionary, 
						 gchar *language)
{
  xmlDocPtr doc;
  xmlNodePtr generale;
  xmlNodePtr personale;
  xmlNodePtr net;
  xmlNodePtr tel;
  xmlNodePtr misc;

  gchar *home, *home_dict;

  home = g_get_home_dir();
  home_dict = g_strdup_printf("%s/.rubrica/dictionary", home);

  if (!g_file_exists(home_dict))
      mkdir(home_dict, S_IRUSR | S_IWUSR | S_IXUSR);
  g_free(home_dict);

  doc = xmlNewDoc("1.0");

  doc->root = xmlNewDocNode(doc, NULL, "Rubrica_dictionary", NULL);
  xmlNodeSetLang(doc->root, language);
  
  generale = xmlNewChild(doc->root, NULL, "General", "");
  xmlSetProp(generale, "Address", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_ADDRESS, NULL));
  xmlSetProp(generale, "Card", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_CARD, NULL)); 
  xmlSetProp(generale, "Modifying", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_MODIFY, NULL));
  xmlSetProp(generale, "Deleting", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_DELETE, NULL));
  xmlSetProp(generale, "Data", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_DATA, NULL));
  
  personale = xmlNewChild(doc->root, NULL, "Personal", "");
  xmlSetProp(personale, "FirstName", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_FIRST_NAME, NULL));
  xmlSetProp(personale, "MiddleName", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_MIDDLE_NAME, NULL));
  xmlSetProp(personale, "LastName", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_LAST_NAME, NULL));
  xmlSetProp(personale, "Profession", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_PROFESSION, NULL));
  xmlSetProp(personale,"Street", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_STREET, NULL));   
  xmlSetProp(personale, "StreetNumber", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_STREET_NUMBER, NULL));
  xmlSetProp(personale,"ZipCode", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_ZIP_CODE, NULL));
  xmlSetProp(personale,"City", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_CITY, NULL));
  xmlSetProp(personale,"Province", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_PROVINCE, NULL));
  xmlSetProp(personale,"Country", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_COUNTRY, NULL));

  net = xmlNewChild(doc->root, NULL, "Net", "");
  xmlSetProp(net, "WebAddress", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_WEB_ADDRESS, NULL));
  xmlSetProp(net,"Web", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_WEB, NULL));   
  xmlSetProp(net, "EMailAddress", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_EMAIL_ADDRESS, NULL));
  xmlSetProp(net,"Email", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_EMAIL, NULL));

  tel = xmlNewChild(doc->root, NULL, "Telephone", "");
  xmlSetProp(tel, "TelephoneNumbers", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_TELEPHONE_LIST , NULL));
  xmlSetProp(tel, "Telephone", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_TELEPHONE_NUMBER, NULL));
  xmlSetProp(tel,"TelephoneType", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_TELEPHONE_TYPE, NULL));

  misc = xmlNewChild(doc->root, NULL, "Misc", "");
  xmlSetProp(misc,"PublicKey",
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_PUBLIC_KEY, NULL));
  xmlSetProp(misc, "Notes", 
	     gconf_client_get_string(client, RUBRICA_KEY_DICT_NOTES, NULL));
  xmlSetProp(misc,"Time", "");


  if( xmlSaveFile(dictionary, doc) == -1)
    {
      g_warning("can't save dictionary");
      
      return FALSE;
    }

  xmlFreeDoc(doc);
  g_free(home);

  return TRUE;
}

/*  copy src into dest
 */
void rubrica_dictionary_write(gchar *src, gchar **dest)
{
  if (src)
    *dest = g_strdup(src);
  else
    dest = NULL;     
}

/*
void rubrica_dictionary_extract_user_dictionary(Dictionary *dict, gpointer pbox)
{
  GtkWidget *eabook, *ecard, *edel, *emod, *edata, *efnname, *ename,
    *ecountry, *eprov, *ecity, *ezip, *estret, *estreetn, *eprof, 
    *ewebadd, *eweb, *emailadd, *email, 
    *etelnum, *tellst, *eteltype,
    *epubk, *enote;
  gchar *buffer = NULL;
  
  eabook   = gtk_object_get_data(GTK_OBJECT(pbox), "entry_address");
  ecard    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_card");
  edel     = gtk_object_get_data(GTK_OBJECT(pbox), "entry_del");
  emod     = gtk_object_get_data(GTK_OBJECT(pbox), "entry_mod");
  edata    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_data");
  efnname  = gtk_object_get_data(GTK_OBJECT(pbox), "entry_fn");
  ename    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_n");
  ecountry = gtk_object_get_data(GTK_OBJECT(pbox), "entry_country");
  eprov    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_prov");
  ecity    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_city");
  ezip     = gtk_object_get_data(GTK_OBJECT(pbox), "entry_zip");
  estret   = gtk_object_get_data(GTK_OBJECT(pbox), "entry_st");
  estreetn = gtk_object_get_data(GTK_OBJECT(pbox), "entry_stn");
  eprof    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_prof");
  ewebadd  = gtk_object_get_data(GTK_OBJECT(pbox), "entry_web_add");
  eweb     = gtk_object_get_data(GTK_OBJECT(pbox), "entry_web");
  emailadd = gtk_object_get_data(GTK_OBJECT(pbox), "entry_mail_add");
  email    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_mail");
  etelnum  = gtk_object_get_data(GTK_OBJECT(pbox), "entry_tel_num");
  tellst   = gtk_object_get_data(GTK_OBJECT(pbox), "entry_tel_lst");
  eteltype = gtk_object_get_data(GTK_OBJECT(pbox), "entry_tel_type");
  epubk    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_pubk");
  enote    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_notes");
  
  buffer = gtk_entry_get_text(GTK_ENTRY(eabook));
  rubrica_dictionary_write(buffer, &dict->address);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(ecard));
  rubrica_dictionary_write(buffer, &dict->card);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(emod));
  rubrica_dictionary_write(buffer,  &dict->mod);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(edel));
  rubrica_dictionary_write(buffer,  &dict->del);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(edata));
  rubrica_dictionary_write(buffer,  &dict->data);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(ename));
  rubrica_dictionary_write(buffer,  &dict->name);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(efnname));
  rubrica_dictionary_write(buffer,  &dict->surn);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(eprof));
  rubrica_dictionary_write(buffer,  &dict->prof);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(estret));
  rubrica_dictionary_write(buffer,  &dict->str);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(estreetn));
  rubrica_dictionary_write(buffer,  &dict->num);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(ezip));
  rubrica_dictionary_write(buffer, &dict->zip);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(ecity));
  rubrica_dictionary_write(buffer, &dict->city);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(eprov));
  rubrica_dictionary_write(buffer,  &dict->prov);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(ecountry));
  rubrica_dictionary_write(buffer,  &dict->st);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(ewebadd));
  rubrica_dictionary_write(buffer,  &dict->webadd);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(eweb));
  rubrica_dictionary_write(buffer,  &dict->web);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(emailadd));
  rubrica_dictionary_write(buffer,  &dict->mailadd);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(email));
  rubrica_dictionary_write(buffer,  &dict->mail);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(tellst));
  rubrica_dictionary_write(buffer,  &dict->tellist);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(etelnum));
  rubrica_dictionary_write(buffer,  &dict->telnum);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(eteltype));
  rubrica_dictionary_write(buffer,  &dict->teltype);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(epubk));
  rubrica_dictionary_write(buffer,  &dict->pubkey);
  buffer = NULL;

  buffer = gtk_entry_get_text(GTK_ENTRY(enote));
  rubrica_dictionary_write(buffer,  &dict->note);
  buffer = NULL;

  rubrica_dictionary_store_dictionary(*dict);
}

void rubrica_dictionary_display_user_dictionary(gpointer pbox)
{
  GtkWidget *eabook, *ecard, *edel, *emod, *edata, *efnname, *ename,
    *ecountry, *eprov, *ecity, *ezip, *estret, *estreetn, *eprof, 
    *ewebadd, *eweb, *emailadd, *email, 
    *etelnum, *tellst, *eteltype,
    *epubk, *enote;
  
  eabook   = gtk_object_get_data(GTK_OBJECT(pbox), "entry_address");
  ecard    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_card");
  edel     = gtk_object_get_data(GTK_OBJECT(pbox), "entry_del");
  emod     = gtk_object_get_data(GTK_OBJECT(pbox), "entry_mod");
  edata    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_data");
  efnname  = gtk_object_get_data(GTK_OBJECT(pbox), "entry_fn");
  ename    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_n");
  ecountry = gtk_object_get_data(GTK_OBJECT(pbox), "entry_country");
  eprov    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_prov");
  ecity    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_city");
  ezip     = gtk_object_get_data(GTK_OBJECT(pbox), "entry_zip");
  estret   = gtk_object_get_data(GTK_OBJECT(pbox), "entry_st");
  estreetn = gtk_object_get_data(GTK_OBJECT(pbox), "entry_stn");
  eprof    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_prof");
  ewebadd  = gtk_object_get_data(GTK_OBJECT(pbox), "entry_web_add");
  eweb     = gtk_object_get_data(GTK_OBJECT(pbox), "entry_web");
  emailadd = gtk_object_get_data(GTK_OBJECT(pbox), "entry_mail_add");
  email    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_mail");
  etelnum  = gtk_object_get_data(GTK_OBJECT(pbox), "entry_tel_num");
  tellst   = gtk_object_get_data(GTK_OBJECT(pbox), "entry_tel_lst");
  eteltype = gtk_object_get_data(GTK_OBJECT(pbox), "entry_tel_type");
  epubk    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_pubk");
  enote    = gtk_object_get_data(GTK_OBJECT(pbox), "entry_notes");  

  gtk_entry_set_text(GTK_ENTRY(eabook), dict.address );
  gtk_entry_set_text(GTK_ENTRY(ecard), dict.card );
  gtk_entry_set_text(GTK_ENTRY(edel), dict.deleting );
  gtk_entry_set_text(GTK_ENTRY(emod), dict.modifying );
  gtk_entry_set_text(GTK_ENTRY(edata), dict.data );
  gtk_entry_set_text(GTK_ENTRY(efnname), dict.firstname );
  gtk_entry_set_text(GTK_ENTRY(ename), dict.lastname );
  gtk_entry_set_text(GTK_ENTRY(ecountry), dict.country);
  gtk_entry_set_text(GTK_ENTRY(eprov), dict.province );
  gtk_entry_set_text(GTK_ENTRY(ecity), dict.city );
  gtk_entry_set_text(GTK_ENTRY(ezip), dict.zipcode );
  gtk_entry_set_text(GTK_ENTRY(estret), dict.street );
  gtk_entry_set_text(GTK_ENTRY(estreetn), dict.streetnumber );
  gtk_entry_set_text(GTK_ENTRY(eprof), dict.profession );
  gtk_entry_set_text(GTK_ENTRY(ewebadd), dict.webaddresses );
  gtk_entry_set_text(GTK_ENTRY(eweb), dict.web );
  gtk_entry_set_text(GTK_ENTRY(emailadd), dict.mailaddresses );
  gtk_entry_set_text(GTK_ENTRY(email), dict.mail );
  gtk_entry_set_text(GTK_ENTRY(etelnum), dict.telnum );
  gtk_entry_set_text(GTK_ENTRY(tellst), dict.tellist );
  gtk_entry_set_text(GTK_ENTRY(eteltype), dict.teltype );
  gtk_entry_set_text(GTK_ENTRY(epubk), dict.pubkey );
  gtk_entry_set_text(GTK_ENTRY(enote), dict.note );
}

*/
