/*
*  Rubrica
*  file: modulo.c
*
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

/*
  modulo rubrica, derivato da gnome-propertybox
*/

#include <gnome.h>
#include <time.h>
#include "rubrica.h"
#include "modulo.h"
#include "modulo_int.h"


enum {
  HELP,
  LAST_SIGNAL
};


typedef void (*ModuloRubricaSignal) (GtkObject *object, gint arg, gpointer data);

static void modulo_rubrica_class_init     (ModuloRubricaClass *klass);
static void modulo_rubrica_init           (ModuloRubrica *modulo);
static void modulo_rubrica_marshal_signal (GtkObject *object, GtkSignalFunc func, 
					   gpointer func_data, GtkArg *args);

static void modulo_rubrica_destroy        (GtkObject *object);
void  modulo_rubrica_info_init(ModuloRubrica *m);

static void modulo_rubrica_dialog_clicked_cb(GnomeDialog *dialog, gint bottone, 
					     gpointer data);
static void modulo_rubrica_aiuto  (ModuloRubrica *modulo);
static void modulo_rubrica_chiudi (ModuloRubrica *modulo);


/* classe genitore */
static GnomeDialogClass *parent_class = NULL;


/* funzione che gestisce i segnali della classe modulo */  
static gint modulo_rubrica_signals[LAST_SIGNAL] = { 0 };


/* conserva il tipo di telefono selezionato, ed attualmente attivo */
static gchar telefono_attivo[12];
static gboolean modificato = FALSE;

/* Widget modulo: make one, return more */
static GtkWidget *ModuloWidget; 

/* modulo widget counter */
static gint count = 0;

/* temporary time variables */
time_t created, changed;



/*    modulo_rubrica_get_type
      ritorna il GtkType del widget ModuloRubrica
*/
GtkType 
modulo_rubrica_get_type(void)
{
  static guint modulo_rubrica_type = 0;
  
  if (!modulo_rubrica_type)
    {
      static const GtkTypeInfo modulo_rubrica_info =
      {
	"ModuloRubrica",
	sizeof(ModuloRubrica),
	sizeof(ModuloRubricaClass),
	(GtkClassInitFunc)  modulo_rubrica_class_init,
	(GtkObjectInitFunc) modulo_rubrica_init,
	NULL, /* riservato per compatibilit */
	NULL, /* riservato per compatibilit */
      };

      modulo_rubrica_type = gtk_type_unique(gnome_dialog_get_type(), 
					    &modulo_rubrica_info);
    }

  return modulo_rubrica_type;
};


/*  inizializzazione della classe ModuloRubrica
*/
static void
modulo_rubrica_class_init(ModuloRubricaClass *klass)
{
  GtkObjectClass *object_class;
  GtkWidgetClass *widget_class;
  GtkWindowClass *window_class;

  object_class = (GtkObjectClass*) klass;
  widget_class = (GtkWidgetClass*) klass;
  window_class = (GtkWindowClass*) klass;

  object_class->destroy = modulo_rubrica_destroy;
 
  parent_class = gtk_type_class(gnome_dialog_get_type());

/*  segnali gestiti dalla classe
*/

 modulo_rubrica_signals[HELP] =
    gtk_signal_new ("help", 
		    GTK_RUN_LAST,
		    object_class->type,
		    GTK_SIGNAL_OFFSET(ModuloRubricaClass, modulo_rubrica_aiuto),
		    modulo_rubrica_marshal_signal,
		    GTK_TYPE_NONE, 1, GTK_TYPE_INT);

 gtk_object_class_add_signals (object_class, modulo_rubrica_signals, LAST_SIGNAL);

 klass->modulo_rubrica_aiuto = NULL;
}


static void
modulo_rubrica_marshal_signal (GtkObject *object, GtkSignalFunc func,
			       gpointer func_data, GtkArg *args)
{
  ModuloRubricaSignal rfunc;

  rfunc = (ModuloRubricaSignal) func;
  (*rfunc) (object, GTK_VALUE_INT(args[0]), func_data);
}


/*  inizializzazione della struttura dati ModuloRubrica
*/
static void
modulo_rubrica_init (ModuloRubrica *modulo)
{
  /* bottoni globali al widget */ 
  GList *button_list;

  /* frame */
  GtkWidget *frame_dati;
  GtkWidget *frame_rete;
  GtkWidget *frame_telefono;
  GtkWidget *frame_note;

  /* etichette notebook */
  GtkWidget *label_dati;
  GtkWidget *label_rete;
  GtkWidget *label_telefono;
  GtkWidget *label_note;

  modulo->notebook = gtk_notebook_new();

  /* bottoni globali alla finestra di dialogo modulo */
  gnome_dialog_append_buttons(GNOME_DIALOG(modulo),
			      GNOME_STOCK_BUTTON_OK,				
			      GNOME_STOCK_BUTTON_HELP,
  			      GNOME_STOCK_BUTTON_CLOSE,
			      NULL);
  /*     bottone di default: -- ok
  */
  gnome_dialog_set_default (GNOME_DIALOG(modulo), 0);

  /*    lista dei bottoni
  */
  button_list = GNOME_DIALOG(modulo)->buttons;
  
  /*     salvo nella struttura dati ModuloRubrica i ptr ai bottoni
  */
  modulo->ok = GTK_WIDGET(button_list->data);

  /*    il prossimo bottone  ...
  */
  button_list = button_list->next;
  modulo->cancella = GTK_WIDGET(button_list->data);

  button_list = button_list->next;
  modulo->aiuto = GTK_WIDGET(button_list->data);
  
  /*    segnali gestiti dal modulo 
	- il segnale clicked  relativo all'intero modulo,
	   il modulo ad emettere il segnale clicked, che
	  viene gestito da dialog_clicked_cb, che dirige
	  l'esecuzione in modo appropriato
  */
  gtk_signal_connect ( GTK_OBJECT(modulo), "clicked",
		       GTK_SIGNAL_FUNC(modulo_rubrica_dialog_clicked_cb),
		       NULL);
  /* connettere ad una funzione che modifica il titolo della 
     finestra, per indicare che  avvenuto un cambiamento 
  */
  
  gtk_box_pack_start (GTK_BOX(GNOME_DIALOG(modulo)->vbox),
		      modulo->notebook,
		      TRUE, TRUE, 0);

  /* Hide dialog on close signal */
  gnome_dialog_close_hides(GNOME_DIALOG(modulo), TRUE);

  /* increase modulo counter */
  count++;

  /*    creo le pagine del notebook:
	-- se si render necessario aggiungere altre pagine
	   nel notobook, si dovr fare qui, utilizzando una funzione 
	   simile a quelle in basso, creare un frame che contiene
	   la pagina e inserire il tutto nel notebook.
  */
  frame_dati = modulo_rubrica_crea_pagina_dati(modulo);
  frame_rete = modulo_rubrica_crea_pagina_rete(modulo);
  frame_telefono = modulo_rubrica_crea_pagina_telefono(modulo);
  frame_note = modulo_rubrica_crea_pagina_note(modulo);

  label_dati = gtk_label_new(_("Data"));
  label_rete = gtk_label_new(_("Net"));
  label_telefono = gtk_label_new(_("Telephone"));
  label_note = gtk_label_new(_("Notes"));

  /*     inserisco le pagine nel notebook
  */
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_dati, label_dati);
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_rete, label_rete);
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_telefono, 
			   label_telefono);
  gtk_notebook_append_page(GTK_NOTEBOOK(modulo->notebook), frame_note, label_note);
  
  gtk_widget_show (modulo->notebook);
}


static void
modulo_rubrica_destroy(GtkObject *object)
{
  ModuloRubrica *modulo;
  
  g_return_if_fail (object != NULL);
  g_return_if_fail (IS_MODULO_RUBRICA(object));

  /*   DA FARE:
       verificare se occorre svuotare le clist
       prima di distruggere il modulo
  */
  modulo = MODULO_RUBRICA(object);

  GTK_OBJECT_CLASS(parent_class)->destroy (object);
}


GtkWidget *
modulo_rubrica_new(MODO_MODULO modo)
{
  GtkWidget *modulo;
  
  if (count == 0)
    {
    modulo = gtk_type_new(modulo_rubrica_get_type());

    modulo_rubrica_set_modulo(modulo);
    }
  else 
    {
    modulo = modulo_rubrica_get_modulo();

    modulo_rubrica_clean_modulo(MODULO_RUBRICA(modulo));
    }

  MODULO_RUBRICA(modulo)->modo = modo;    

  /* init some data scructures
   */
  modulo_rubrica_info_init(MODULO_RUBRICA(modulo));

  /*    set modulo notebook default page
  */
  gtk_notebook_set_page(GTK_NOTEBOOK(MODULO_RUBRICA(modulo)->notebook), 0);

  /* set default telephone
   */
  strcpy(telefono_attivo, "home");  

  return GTK_WIDGET(modulo);

}

/*   return saved modulo pointer 
*/
GtkWidget *modulo_rubrica_get_modulo(void)
{
  return (GtkWidget *) ModuloWidget;
}

/*  store modulo widget for future
*/

void modulo_rubrica_set_modulo(GtkWidget *wid)
{
  g_return_if_fail( wid != NULL);

  ModuloWidget = (GtkWidget*) wid;
}

void modulo_rubrica_clean_modulo(ModuloRubrica *m)
{
  g_return_if_fail(m != NULL);

  /*    text box initialization
   */
  gtk_entry_set_text(GTK_ENTRY(m->scheda), "");
  gtk_entry_set_text(GTK_ENTRY(m->nome), "");
  gtk_entry_set_text(GTK_ENTRY(m->cognome), "");
  gtk_entry_set_text(GTK_ENTRY(m->professione), "");
  gtk_entry_set_text(GTK_ENTRY(m->via), "");
  gtk_entry_set_text(GTK_ENTRY(m->numero), "");
  gtk_entry_set_text(GTK_ENTRY(m->cap), "");
  gtk_entry_set_text(GTK_ENTRY(m->citta), "");
  gtk_entry_set_text(GTK_ENTRY(m->provincia), "");
  gtk_entry_set_text(GTK_ENTRY(m->stato), "");
  gtk_entry_set_text(GTK_ENTRY(m->web), "");
  gtk_entry_set_text(GTK_ENTRY(m->mail), "");
  gtk_entry_set_text(GTK_ENTRY(m->telefono), "");

  gtk_clist_clear(GTK_CLIST(m->clist_web));
  gtk_clist_clear(GTK_CLIST(m->clist_mail));
  gtk_clist_clear(GTK_CLIST(m->clist_telefono));

  gtk_editable_delete_text(GTK_EDITABLE(m->note), 0, -1);
}

/*   funzione di callback che gestisce il 
     segnale "clicked" emesso dal modulo
*/  
static void
modulo_rubrica_dialog_clicked_cb(GnomeDialog * dialog, gint button, gpointer data)
{
  ModuloRubrica *mod;

  g_return_if_fail(dialog != NULL);
  g_return_if_fail(IS_MODULO_RUBRICA(dialog));
  
  mod = MODULO_RUBRICA (dialog);

  switch(button) 
    {
    case 0:   /* cliccato ok */          
      if (mod->modo == NUOVO_MODULO) 
	{
	  rubrica_view_inc_indirizzi();
	  modulo_rubrica_estrai_inserisci_e_chiudi(mod);
	}
      if (mod->modo == MODIFICA_MODULO) 
	{
	  modificato = TRUE;
	  modulo_rubrica_estrai_sostituisci_e_chiudi(mod);       
	}
      
      break;

    case 1:   /* cliccato aiuto */
      modulo_rubrica_aiuto (MODULO_RUBRICA (dialog));
      break;

    case 2:   /* cliccato chiudi */
      if (rubrica_is_empty && !modificato)
	modificato = FALSE;
      modulo_rubrica_chiudi (MODULO_RUBRICA (dialog));
      break;
    default:  /* non si deve arrivare a questo punto    */
              /* se si  qui, si  verificato un errore */
      g_assert_not_reached();
    }
}


void 
modulo_rubrica_info_init(ModuloRubrica *m)
{
  g_return_if_fail(m != NULL);

  modificato = FALSE;
  
  m->webinfo.riga = 0;
  m->webinfo.colonna = 0;
  m->webinfo.selezionato = FALSE;
  m->mailinfo.riga = 0;
  m->mailinfo.colonna = 0;
  m->mailinfo.selezionato = FALSE;
  m->telinfo.riga = 0;
  m->telinfo.colonna = 0;
  m->telinfo.selezionato = FALSE;
}


void 
modulo_rubrica_estrai_inserisci_e_chiudi(ModuloRubrica *m)
{
  RubricaItem *r;

  g_return_if_fail(m != NULL);
  g_return_if_fail(IS_MODULO_RUBRICA(m));

  /* estrazione dei dati contenuti nel modulo */
  r = modulo_rubrica_estrai_dati(m);

  /* Imposta la data di creazione e ultima modifica */
  r->created = r->last_change = time(NULL); 
  
  /* inserimento dei dati nella rubrica */
  rubrica_inserisci_elemento(r); 

  /* setto il flag di lista vuota a falso */
  rubrica_set_empty(FALSE);

  /* visualizzazione della scheda nell'apposita clist */
  rubrica_inserisci_scheda(r);

  /* chiudo il modulo */
  modulo_rubrica_chiudi(m);
}

void 
modulo_rubrica_estrai_sostituisci_e_chiudi(ModuloRubrica *m)
{
  RubricaItem *r;
  InfoRubrica info;

  g_return_if_fail(m != NULL);
  g_return_if_fail(IS_MODULO_RUBRICA(m));

  /* estrazione dei dati contenuti nel modulo */
  r = modulo_rubrica_estrai_dati(m);

  /* Imposta la data di ultima modifica */
  r->created = created;
  r->last_change = time(NULL);

  rubrica_view_get_info(&info,VISTA_SCHEDE);

  /* inserimento dei dati nella rubrica */
  rubrica_modifica_elemento(r);
  
  /* setto il flag di lista vuota a falso */
  rubrica_set_empty(FALSE);
  
  /* visualizzazione della scheda nell'apposita clist */
  rubrica_modifica_scheda(r);

  /* visualizzo i nuovi dati nella lista dati */
  rubrica_mostra_scheda(r); 

  /* chiudo il modulo */
  modulo_rubrica_chiudi(m);
}


/*   DA TERMINARE 
*/
static void
modulo_rubrica_aiuto (ModuloRubrica *modulo)
{
  gint page;
  
  page = gtk_notebook_get_current_page (GTK_NOTEBOOK (modulo->notebook));
  gtk_signal_emit (GTK_OBJECT (modulo), modulo_rubrica_signals[HELP],page);

  /* to do */
}


static void
modulo_rubrica_chiudi (ModuloRubrica *modulo)
{
  gnome_dialog_close(GNOME_DIALOG(modulo));
}


gboolean 
modulo_rubrica_modulo_is_modificato()
{
  return (gboolean) modificato;
}


/*   funzioni per manipolare i dati contenuti nel widget

     estrae i dati contenuti nella finestra di dialogo e 
     li salva nella rubrica
*/
RubricaItem 
*modulo_rubrica_estrai_dati(ModuloRubrica *modulo)
{
  RubricaItem *r;
  TelNum *tt;
  GtkCList *clist;

  gint riga;
  gint rows;
  gchar *web;
  gchar *mail;
  gchar *numero;
  gchar *tipo;

  GList *weblist;  
  GList *maillist; 
  GList *tellist;

  g_return_val_if_fail(modulo != NULL, NULL);
  g_return_val_if_fail(IS_MODULO_RUBRICA(modulo), NULL);

  /* alloco la memoria necessaria per contenere i dati */
  r = g_malloc (sizeof(RubricaItem));

  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(modulo->editabile)))
    r->editabile = TRUE;
  else 
    r->editabile = FALSE;

  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(modulo->cancellabile)))
    r->cancellabile = TRUE;
  else 
    r->cancellabile = FALSE; 

  /* estrazione dei dati relativi al nominativo, domicilio, ... */
  r->scheda      = g_strdup(gtk_entry_get_text(GTK_ENTRY(modulo->scheda)));
  r->nome        = g_strdup(gtk_entry_get_text(GTK_ENTRY(modulo->nome)));
  r->cognome     = g_strdup(gtk_entry_get_text(GTK_ENTRY(modulo->cognome )));
  r->professione = g_strdup(gtk_entry_get_text(GTK_ENTRY(modulo->professione)));
  r->via         = g_strdup(gtk_entry_get_text(GTK_ENTRY(modulo->via)));
  r->numero      = g_strdup(gtk_entry_get_text(GTK_ENTRY(modulo->numero)));
  r->cap         = g_strdup(gtk_entry_get_text(GTK_ENTRY(modulo->cap)));
  r->citta       = g_strdup(gtk_entry_get_text(GTK_ENTRY(modulo->citta)));
  r->provincia   = g_strdup(gtk_entry_get_text(GTK_ENTRY(modulo->provincia)));
  r->stato       = g_strdup(gtk_entry_get_text(GTK_ENTRY(modulo->stato)));

  /* estrazione dei dati dalle liste, web, mail e telefonica */
  
  /* NOTA:
     faccio iniziare riga da zero, mentre il numero di elementi inseriti
     nelle clist inizia da uno. Allora devo fermare il conto a rows-1 se
     inizio con riga da zero. Mi fermo a rows, se far iniziare riga da 1
  */
  
  /*    web
   */
  clist = GTK_CLIST(modulo->clist_web);
  rows = clist->rows;
  riga = 0;
  weblist = NULL;
  while ( riga < rows )
    {
      gchar *buffer;

      gtk_clist_get_text(GTK_CLIST(modulo->clist_web), riga, 1, &web);

      buffer = g_strdup(web);
      weblist = g_list_append(weblist, buffer);
      riga++;
    }
  r->web_list = weblist;  // la lista delle pagine web
  r->nweb = rows;         // il numero degli url web

  /*    mail
  */
  clist = GTK_CLIST(modulo->clist_mail);
  rows = clist->rows;
  riga = 0;
  maillist = NULL;
  while (riga < rows )
    {
      gchar *buffer;
      
      gtk_clist_get_text(GTK_CLIST(modulo->clist_mail), riga, 1, &mail);

      buffer = g_strdup(mail);
      maillist = g_list_append(maillist, buffer);
      riga++;
    }
  r->mail_list = maillist;
  r->nmail = rows;

  /*    Telefono
  */
  clist = GTK_CLIST(modulo->clist_telefono);
  rows = clist->rows;
  riga = 0;
  tellist = NULL;
  while ( riga < rows )
    {
      tt = g_malloc(sizeof(TelNum));

      gtk_clist_get_text(GTK_CLIST(modulo->clist_telefono), riga, 1, &numero);
      gtk_clist_get_text(GTK_CLIST(modulo->clist_telefono), riga, 2, &tipo);
         
      tt->numero_telefono = g_strdup(numero);
      tt->tipo = g_strdup(tipo);

      tellist = g_list_append(tellist, tt);
      riga++;
    }
  r->tel_list = tellist;
  r->ntel = rows;
  
  /*     Note
  */
  r->note = g_strdup(gtk_editable_get_chars(GTK_EDITABLE(modulo->note), 0, -1));

  return (RubricaItem *) r;
}

/*
    visualizza i dati contenuti nell'elemento di 
    rubrica, nella finestra di dialogo
*/
void 
modulo_rubrica_inserisci_dati(ModuloRubrica *m, RubricaItem *r)
{
  GList *weblist; 
  GList *maillist;
  GList *tellist;
  
  gint righe;


  g_return_if_fail(m != NULL);
  g_return_if_fail(IS_MODULO_RUBRICA(m));

  /* estrazione dei dati relativi al nominativo, domicilio, ... */
  if (r->editabile)
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m->editabile), TRUE);
  else 			 
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m->editabile), FALSE);

  if (r->cancellabile)
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m->cancellabile), TRUE);
  else 			 
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m->cancellabile), FALSE);  
 
  gtk_entry_set_text(GTK_ENTRY(m->scheda), r->scheda );
  gtk_entry_set_text(GTK_ENTRY(m->nome), r->nome );
  gtk_entry_set_text(GTK_ENTRY(m->cognome), r->cognome );
  gtk_entry_set_text(GTK_ENTRY(m->professione), r->professione );
  gtk_entry_set_text(GTK_ENTRY(m->via), r->via );
  gtk_entry_set_text(GTK_ENTRY(m->numero), r->numero );
  gtk_entry_set_text(GTK_ENTRY(m->cap), r->cap );
  gtk_entry_set_text(GTK_ENTRY(m->citta), r->citta );
  gtk_entry_set_text(GTK_ENTRY(m->provincia), r->provincia );
  gtk_entry_set_text(GTK_ENTRY(m->stato), r->stato );
  
  created = r->created;
  changed = r->last_change;

  /* inserimento dei dati dalle liste, web, mail e telefonica */
  
  /*    web
   */
  if (r->web_list) {
    weblist = r->web_list;
    righe = r->nweb;
  }   
  else {
    weblist = NULL;
    righe = 0;
  }
  while (righe)
    {    
      gchar *buffer[3] = {NULL, NULL, NULL};
      
      buffer[1] = g_strdup(weblist->data);
      gtk_clist_append(GTK_CLIST(m->clist_web), buffer);
      weblist = g_list_next(weblist);
      righe--;
    }
  
  /*    mail
   */
  if (r->mail_list) {
    righe = r->nmail;
    maillist = r->mail_list;
  }
  else {
    righe = 0;
    maillist = NULL;
  }
  while (righe)
    {
      gchar *buffer[3] = {NULL, NULL, NULL};

      buffer[1] = g_strdup(maillist->data);
      gtk_clist_append(GTK_CLIST(m->clist_mail), buffer);
      maillist = g_list_next(maillist);
      righe--;
    }

  /*    Telefono
   */
  if (r->tel_list) {
    righe = r->ntel;
    tellist = r->tel_list;
  }
  else {
    righe = 0;
    tellist = NULL;
  }
  while (righe)
    {       
      /* buffer[0] riservato per l'eventuale pixmap */
      gchar *buffer[4] = {NULL, NULL, NULL, NULL};
      TelNum *tt = (TelNum*) tellist->data;

      buffer[1] = g_strdup(tt->numero_telefono);
      buffer[2] = g_strdup(tt->tipo);
      gtk_clist_append(GTK_CLIST(m->clist_telefono), buffer);
      tellist = g_list_next(tellist);     
      righe--;
    }

  /*     Note
  */
  gtk_text_insert(GTK_TEXT(m->note), NULL, NULL, NULL, r->note, -1);
}

void 
modulo_rubrica_modifica_elemento(RubricaItem *r)
{
  GtkWidget *modulo;

  modulo = modulo_rubrica_new(MODIFICA_MODULO);

  modulo_rubrica_inserisci_dati(MODULO_RUBRICA(modulo), r);  
  gtk_widget_show(modulo);
}


gchar 
*modulo_rubrica_get_telefono_attivo(void)
{
  return (gchar *) g_strdup(telefono_attivo);
}


void 
modulo_rubrica_set_telefono_attivo(gchar *str)
{
  strcpy(telefono_attivo, str);
}


TELEPHONE_TYPE
modulo_rubrica_tipo_telefono_int(gchar *tipo)
{
  if (!tipo)
    return TELEPHONE_UNKNOWN;

  if ((strcmp(tipo, "home") == 0) ||
      (strcmp(tipo, "Casa") == 0))
    return TELEPHONE_HOME;

  if ((strcmp(tipo, "work") == 0) ||
      (strcmp(tipo, "Ufficio") == 0))
    return TELEPHONE_WORK;

  if ((strcmp(tipo, "fax") == 0) ||
      (strcmp(tipo, "Fax") == 0))
    return TELEPHONE_FAX;
  
  if ((strcmp(tipo, "cellphone") == 0) ||
      (strcmp(tipo, "Cellulare") == 0))
    return TELEPHONE_CELLPHONE;

  if ((strcmp(tipo, "other") == 0) ||
      (strcmp(tipo, "Altro") == 0))
    return TELEPHONE_OTHER;

  return TELEPHONE_UNKNOWN;
}
























