/*
*  Rubrica
*  file: prefer.h
*
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef __RUBRICA_PREFERENCES_H
#define __RUBRICA_PREFERENCES_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <gconf/gconf-client.h>


#define RUBRICA_KEY_LAST_RUN        "/apps/rubrica/last_run"
#define RUBRICA_KEY_LAST_BOOK       "/apps/rubrica/last_book"

#define RUBRICA_KEY_SHOW            "/apps/rubrica/file/show_path"
#define RUBRICA_KEY_HAVE_BOOK       "/apps/rubrica/file/load_addressbook"
#define RUBRICA_KEY_BOOK            "/apps/rubrica/file/addressbook"
#define RUBRICA_KEY_HAVE_FOLDER     "/apps/rubrica/file/have_default_folder"
#define RUBRICA_KEY_FOLDER          "/apps/rubrica/file/folder"
#define RUBRICA_KEY_BACKUP          "/apps/rubrica/file/do_backup"
#define RUBRICA_KEY_COMPRESS        "/apps/rubrica/file/compress_addressbook"
#define RUBRICA_KEY_RATE            "/apps/rubrica/file/compression_rate"
#define RUBRICA_KEY_INCREASE        "/apps/rubrica/general/increasing_order"
#define RUBRICA_KEY_ALPHA_ORDER     "/apps/rubrica/general/alphabetic_order"
#define RUBRICA_KEY_DATE_ORDER      "/apps/rubrica/general/date_order"
#define RUBRICA_KEY_SENSITIVE       "/apps/rubrica/general/case_sensitive_search"
#define RUBRICA_KEY_COMPLETE        "/apps/rubrica/general/complete_string_search"
#define RUBRICA_KEY_INCOMPLETE      "/apps/rubrica/general/incomplete_string_search"
#define RUBRICA_KEY_EXIT            "/apps/rubrica/general/confirm_exit"
#define RUBRICA_KEY_TIPS            "/apps/rubrica/general/show_tips"
#define RUBRICA_KEY_DEFAULT         "/apps/rubrica/translation/use_default_dictionary"
#define RUBRICA_KEY_EXTERNAL        "/apps/rubrica/translation/use_external_dictionary"
#define RUBRICA_KEY_ITALIAN         "/apps/rubrica/translation/use_italian_dictionary"
#define RUBRICA_KEY_ENGLISH         "/apps/rubrica/translation/use_english_dictionary" 
#define RUBRICA_KEY_HAS_DICTIONARY  "/apps/rubrica/translation/user_has_dictionary"
#define RUBRICA_KEY_USER_DICTIONARY "/apps/rubrica/translation/user_dictionary_name" 


#define RUBRICA_KEY_DICT_CARD              "/apps/rubrica/dictionary/card"
#define RUBRICA_KEY_DICT_MODIFY            "/apps/rubrica/dictionary/modify"
#define RUBRICA_KEY_DICT_DELETE            "/apps/rubrica/dictionary/delete"
#define RUBRICA_KEY_DICT_ADDRESS           "/apps/rubrica/dictionary/address"
#define RUBRICA_KEY_DICT_DATA              "/apps/rubrica/dictionary/data"
#define RUBRICA_KEY_DICT_LAST_NAME         "/apps/rubrica/dictionary/last_name"
#define RUBRICA_KEY_DICT_FIRST_NAME        "/apps/rubrica/dictionary/first_name"
#define RUBRICA_KEY_DICT_MIDDLE_NAME       "/apps/rubrica/dictionary/middle_name"
#define RUBRICA_KEY_DICT_PROFESSION        "/apps/rubrica/dictionary/profession"
#define RUBRICA_KEY_DICT_STREET            "/apps/rubrica/dictionary/street"
#define RUBRICA_KEY_DICT_STREET_NUMBER     "/apps/rubrica/dictionary/street_number"
#define RUBRICA_KEY_DICT_ZIP_CODE          "/apps/rubrica/dictionary/zip_code"
#define RUBRICA_KEY_DICT_CITY              "/apps/rubrica/dictionary/city"
#define RUBRICA_KEY_DICT_PROVINCE          "/apps/rubrica/dictionary/province"
#define RUBRICA_KEY_DICT_COUNTRY           "/apps/rubrica/dictionary/country"
#define RUBRICA_KEY_DICT_WEB               "/apps/rubrica/dictionary/web"
#define RUBRICA_KEY_DICT_WEB_ADDRESS       "/apps/rubrica/dictionary/web_address"
#define RUBRICA_KEY_DICT_EMAIL             "/apps/rubrica/dictionary/email"
#define RUBRICA_KEY_DICT_EMAIL_ADDRESS     "/apps/rubrica/dictionary/email_address"
#define RUBRICA_KEY_DICT_TELEPHONE_LIST    "/apps/rubrica/dictionary/telephone_list"
#define RUBRICA_KEY_DICT_TELEPHONE_TYPE    "/apps/rubrica/dictionary/telephone_type"
#define RUBRICA_KEY_DICT_TELEPHONE_NUMBER  "/apps/rubrica/dictionary/telephone_number"
#define RUBRICA_KEY_DICT_PUBLIC_KEY        "/apps/rubrica/dictionary/public_key"
#define RUBRICA_KEY_DICT_NOTES             "/apps/rubrica/dictionary/notes"


void rubrica_preferences_apply (GtkWidget* prefbox);
void rubrica_preferences_revert(GtkWidget* prefbox);

void rubrica_preferences_update_sensitivity(GtkWidget *prefbox);

/*  Setting funcions:
    when the preferences window dialog is called, 
    widgets are filled with values stored in changeset
*/
void rubrica_preferences_configure_radio(GtkWidget *radio1, 
					 GtkWidget *radio2,
					 GConfClient *client, 
					 gchar *key1,
					 gchar *key2);
void 
rubrica_preferences_configure_radio_dictionary(GtkWidget *radio1, 
					       GtkWidget *radio2,
					       GConfClient *client, 
					       gchar *key1,
					       gchar *key2);

void rubrica_preferences_configure_check(GtkWidget *check, 
					 GConfClient *client, 
					 gchar *key);

void rubrica_preferences_configure_spin(GtkWidget *check,
					GtkWidget *spin,
					GConfClient *client, 
					gchar *key1,
					gchar *key2);

void rubrica_preferences_configure_entry(GtkWidget *entry, 
					 GConfClient *client, 
					 gchar *key);

void rubrica_preferences_configure_label(GtkWidget *label, 
					 GConfClient *client, 
					 gchar *key);

void rubrica_preferences_configure_checked_entry(GtkWidget *check,
						 GtkWidget *gnome_entry,
						 GtkWidget *entry, 
						 GConfClient *client, 
						 gchar *key1, 
						 gchar *key2);

/* revert funcions: 
   when revert button is clicked, the values stored in 
   revert change set are replaced to the current values
*/
void rubrica_preferences_revert_check_button(GtkWidget *dialog, 
					     GConfChangeSet* cs, 
					     gchar* key);

void rubrica_preferences_revert_radio_buttons(GtkWidget *dialog, 
					      GConfChangeSet* cs, 
					      gchar* key1, 
					      gchar* key2);

void rubrica_preferences_revert_checked_entry(GtkWidget *dialog, 
					      GConfChangeSet* cs, 
					      gchar* key1,
					      gchar* key2);

void rubrica_preferences_revert_spin_button(GtkWidget *dialog,
					    GConfChangeSet* cs, 
					    gchar* key1,
					    gchar* key2);

void rubrica_preferences_revert_entry(GtkWidget *dialog, 
				      GConfChangeSet* cs, 
				      gchar* key);

GConfClient *rubrica_preferences_get_client(void);

gint rubrica_preferences_get_last_run(void);
gchar *rubrica_preferences_get_last_book(void);

gboolean rubrica_preferences_get_have_default_addressbook(void);
gchar *rubrica_preferences_get_book(void);
gboolean rubrica_preferences_get_have_default_folder(void);
gchar* rubrica_preferences_get_default_folder(void);
gboolean rubrica_preferences_get_do_backup(void);
gboolean rubrica_preferences_get_compress(void);
gint rubrica_preferences_get_compress_rate();
gboolean rubrica_preferences_get_increasing_order(void);
gboolean rubrica_preferences_get_alphabetic_order(void);
gboolean rubrica_preferences_get_date_order(void);
gboolean rubrica_preferences_get_case_sensitive_search(void);
gboolean rubrica_preferences_get_complete_search(void);
gboolean rubrica_preferences_get_incomplete_search(void);
gboolean rubrica_preferences_get_exit(void);
gboolean rubrica_preferences_get_tips(void);
gboolean rubrica_preferences_get_use_default_dictionary(void);
gboolean rubrica_preferences_get_use_user_dictionary(void);
gboolean rubrica_preferences_get_use_italian_dictionary(void);
gboolean rubrica_preferences_get_use_english_dictionary(void);
gboolean rubrica_preferences_get_user_has_dictionary(void);
gchar* rubrica_preferences_get_user_dictionary(void);
gchar* rubrica_preferences_get_language(void);


gboolean rubrica_preferences_get_user_dictionary_loaded();
#define dictionary_loaded() rubrica_preferences_get_user_dictionary_loaded()

void rubrica_preferences_set_last_run(time_t last_run);
void rubrica_preferences_set_last_book(gchar *filename, gchar *key);
void rubrica_preferences_set_compress_rate(gint rate);
void rubrica_preferences_set_increasing_order(gboolean state);
void rubrica_preferences_set_alphabetic_order(gboolean state);
void rubrica_preferences_set_date_order(gboolean state);
void rubrica_preferences_set_case_sensitive_search(gboolean state);
void rubrica_preferences_set_complete_search(gboolean state);
void rubrica_preferences_set_incomplete_search(gboolean state);
void rubrica_preferences_set_tips(gboolean state);

void rubrica_preferences_set_user_dictionary(gchar *dict);
void rubrica_preferences_set_user_dictionary_loaded(gboolean state);

/*
gboolean preferences_get_load_ab(void);
gboolean preferences_get_alpha_order(void);
gboolean preferences_get_date_order(void);
gboolean preferences_get_increasing(void);
gboolean preferences_get_exit_confirm(void);
gboolean preferences_get_do_backup(void);
gboolean preferences_get_zip_addressbook(void);
gboolean preferences_get_use_dictionary(void);
gboolean preferences_get_use_english(void);
*/




#endif
